@@ -1,4 +1,4 @@
-import types, re
+import types, re, decimal
 from datetime import date, time, datetime
 
 from django.utils.safestring import mark_safe
@@ -10,6 +10,8 @@ from django.utils import dateformat
 from django.conf import settings
 from django.core.exceptions import ObjectDoesNotExist
 
+from djangoplus.templatetags.djangoplus_tags import moneyformat
+
 class ModelInfoBase(object):
     class _Meta:
         model = None
@@ -38,14 +40,21 @@ class ModelInfoBase(object):
             return None
 
     def get_field_display_text(self, f_name):
-        f = self.get_field(f_name)
+        """Returns the display text for the informed field. This allows you
+        declare a method like 'get_FIELD_display' to returns a customized
+        display text."""
 
-        if f:
-            return f.verbose_name
-        elif hasattr(self, 'get_%s_display'%f_name):
-            return getattr(self, 'get_%s_display'%f_name)()
+        if hasattr(self, 'get_%s_display'%f_name):
+            ret = getattr(self, 'get_%s_display'%f_name)()
+        else:
+            f = self.get_field(f_name)
 
-        return f_name
+            if f:
+                ret = f.verbose_name
+            else:
+                ret = f_name
+
+        return ret[0] == ret[0].lower() and ret.capitalize() or ret
 
     def get_field_display_value(self, f_name, instance):
         field = self.get_field(f_name)
@@ -157,7 +166,6 @@ class ModelInfo(ModelInfoBase):
                 
         for f_name in s_fields:
             f_display = self.get_field_display_text(f_name)
-            f_display = f_display[0] == f_display[0].lower() and f_display.capitalize() or f_display
 
             f_value = self.get_field_display_value(f_name)
             f_value = self.get_linkable_field_value(self.instance, f_name, f_value)
@@ -210,7 +218,7 @@ class ModelList(ModelInfoBase):
 
     class _Meta(ModelInfoBase._Meta):
         td_template = '<td class="%(field_name)s">%(value)s</td>'
-        th_template = '<th>%s</th>'
+        th_template = '<th class="%(field_name)s">%(display)s</th>'
         tr_template = '<tr>%s</tr>'
         thead_template = '<thead><tr>%s</tr></thead>'
         tbody_template = '<tbody>%s</tbody>'
@@ -221,7 +229,7 @@ class ModelList(ModelInfoBase):
         show_header = True
         show_summary = True
         summary_fields = None
-        summary_td_template = '<td>%(val)s</td>'
+        summary_td_template = '<td class="%(field_name)s">%(value)s</td>'
         summary_tr_template = '<tr>%(cells)s</tr>'
 
     def __init__(self, queryset, *args, **kwargs):
@@ -281,7 +289,7 @@ class ModelList(ModelInfoBase):
             f_display = self.get_field_display_text(f_name)
             f_display = f_display[0] == f_display[0].lower() and f_display.capitalize() or f_display
 
-            thead.append(self._meta.th_template % f_display)
+            thead.append(self._meta.th_template%{'field_name': f_name, 'display': f_display})
 
         return self._meta.thead_template %(''.join(thead) + self.render_buttons_header())
 
@@ -310,8 +318,12 @@ class ModelList(ModelInfoBase):
             else:
                 val = '&nbsp'
             
+            if isinstance(val, decimal.Decimal):
+                val = moneyformat(val)
+
             tsummary.append(self._meta.summary_td_template%{
-                'val': val,
+                'field_name': f_name,
+                'value': val,
                 })
 
         return self._meta.summary_tr_template%{
@@ -384,6 +396,9 @@ class ModelList(ModelInfoBase):
                     force=not self._meta.list_display_links and i == 0,
                     )
 
+            if isinstance(f_value, decimal.Decimal):
+                f_value = moneyformat(f_value)
+
             if self._meta.show_if_none or f_value is not None:
                 row.append(td_template%{'field_name': f_name, 'value': f_value})
             else:
