@@ -21,9 +21,11 @@ class DynamicTemplate(models.Model):
 
 class StaticFile(models.Model):
     file = models.FileField(upload_to=app_settings.STATIC_FILES_PATH)
+    label = models.CharField(max_length=50, blank=True)
+    group = models.CharField(max_length=50, blank=True)
 
     def __unicode__(self):
-        return self.file.name
+        return self.label or self.file.name
 
 # SIGNALS AND LISTENERS
 from django.db.models import signals
