@@ -88,3 +88,24 @@ def run_tests(test_labels, verbosity=1, interactive=True, extra_tests=[]):
 
     return old_run_tests(test_labels, verbosity, interactive, extra_tests)
 
+def url_status_code(url, status_code=200, content=None, client=None, return_response=False):
+    """Checks if the informed URL returns the wanted status_code"""
+    if not client:
+        from django.test.client import Client
+        client = Client()
+
+    resp = client.get(url)
+
+    if return_response:
+        return resp
+
+    ret = True
+
+    if status_code and status_code == resp.status_code:
+        ret = ret and True
+
+    if content and content == resp.status_code:
+        ret = ret and True
+
+    return ret
+
